@@ -1,9 +1,8 @@
 import os
 
 import connexion
-
-from opera.api.openapi import encoder
 from opera.api.log import get_logger
+from opera.api.openapi import encoder
 
 DEBUG = os.getenv("DEBUG", "false") == "true"
 logger = get_logger(__name__)
@@ -18,8 +17,8 @@ def main():
         server = "tornado"
 
     app = connexion.App(__name__, specification_dir="./openapi/openapi/", server=server, options=dict(
-        serve_spec=False,
-        swagger_ui=False
+        serve_spec=DEBUG,
+        swagger_ui=DEBUG
     ))
     app.app.json_encoder = encoder.JSONEncoder
     app.add_api("openapi.yaml", arguments={"title": "xOpera API"}, pythonic_params=True)
